package org.springframework.cloud.consul.config.encrypt;

public class EncryptConfig {

    private static final String PASSWORD_KEY = "tsf_config_encrypt_password";

    static {
        // 环境变量
        if (null != System.getenv(PASSWORD_KEY)) {
            password = System.getenv(PASSWORD_KEY);
        }
        // JVM参数
        if (null != System.getProperty(PASSWORD_KEY)) {
            password = System.getProperty(PASSWORD_KEY);
        }
    }

    /**
     * 加密前缀
     */
    public static String ENCRYPT_PREFIX = "ENC(";
    /**
     * 加密后缀
     */
    public static String ENCRYPT_SUFFIX = ")";

    /**
     * 是否开启配置
     */
    private static Boolean enabled = true;

    /**
     * 密码
     */
    private static String password;

    /**
     * 加解密提供器类名
     */
    private static String providerClass = "org.springframework.cloud.consul.config.encrypt.ConfigEncryptAESProvider";

    public static Boolean getEnabled() {
        return enabled;
    }

    public void setEnabled(Boolean enabled) {
        EncryptConfig.enabled = enabled;
    }

    public static String getPassword() {
        return EncryptConfig.password;
    }

    public static void setPassword(String password) {
        EncryptConfig.password = password;
    }

    public static ConfigEncryptProvider getProvider() {
        return ConfigEncryptProviderFactory.getInstance();
    }

    public static String getProviderClass() {
        return providerClass;
    }

    public static void setProviderClass(String providerClass) {
        EncryptConfig.providerClass = providerClass;
    }

    /**
     * 是否需要进行解密
     * 
     * @param content 判断对象
     * @return true：需要解密；false：不需要解密
     */
    public static Boolean needDecrypt(Object content) {
        if (null == content) {
            return false;
        } else {
            String stringValue = String.valueOf(content);
            return stringValue.startsWith(ENCRYPT_PREFIX) && stringValue.endsWith(ENCRYPT_SUFFIX);
        }
    }

    /**
     * 获取真实密文
     * 
     * @param content 原始配置值
     * @return 真实密文
     */
    public static String realContent(Object content) {
        if (null != content) {
            String stringValue = String.valueOf(content);
            return stringValue.substring(ENCRYPT_PREFIX.length(), stringValue.length() - ENCRYPT_SUFFIX.length());
        }
        return null;
    }

}
