package org.springframework.cloud.consul.config.encrypt;

import java.io.IOException;
import java.util.Enumeration;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.env.PropertiesPropertySourceLoader;
import org.springframework.core.env.PropertiesPropertySource;
import org.springframework.core.env.PropertySource;
import org.springframework.core.io.Resource;
import org.springframework.core.io.support.PropertiesLoaderUtils;

/**
 * 加密的属性处理
 *
 * @author hongweizhu
 */
public class EncryptPropertiesPropertySourceLoader extends PropertiesPropertySourceLoader {

    private static final Logger log = LoggerFactory.getLogger(EncryptPropertiesPropertySourceLoader.class);

    @Override
    public PropertySource<?> load(String name, Resource resource, String profile) throws IOException {
        if (profile == null) {
            Properties properties = PropertiesLoaderUtils.loadProperties(resource);
            if (!properties.isEmpty()) {
                // 解密配置
                decryptProperties(properties);
                return new PropertiesPropertySource(name, properties);
            }
        }
        return null;
    }

    private void decryptProperties(Properties properties) {
        if (EncryptConfig.getEnabled()) {
            // 解密
            Enumeration<?> propertyNames = properties.propertyNames();
            while (propertyNames.hasMoreElements()) {
                String propertyName = String.valueOf(propertyNames.nextElement());
                String propertyValue = properties.getProperty(propertyName);
                if (EncryptConfig.needDecrypt(propertyValue)) {
                    log.debug("[TSF SDK] Decrypt %s: %s", propertyName, propertyValue);
                    String decryptedContent = EncryptConfig.getProvider()
                            .decrypt(EncryptConfig.realContent(propertyValue), EncryptConfig.getPassword());
                    properties.setProperty(propertyName, decryptedContent);
                }
            }
        }
    }
}
